import { Injectable } from '@nestjs/common';
import { IndexSeasonPeriodManager } from './managers/index-season-period.manager';
import { SeasonPeriodReadService } from '../../data/services/season-period-read.service';
import { SeasonPeriodEntity } from '../entities/season-period.entity';
import { PaginationResponse } from 'src/core/response/domain/ok-response.interface';
import { BaseReadOrchestrator } from 'src/core/modules/domain/usecase/orchestrators/base-read.orchestrator';
import { DetailSeasonPeriodManager } from './managers/detail-season-period.manager';
import { TABLE_NAME } from 'src/core/strings/constants/table.constants';

@Injectable()
export class SeasonPeriodReadOrchestrator extends BaseReadOrchestrator<SeasonPeriodEntity> {
  constructor(
    private indexManager: IndexSeasonPeriodManager,
    private detailManager: DetailSeasonPeriodManager,
    private serviceData: SeasonPeriodReadService,
  ) {
    super();
  }

  async index(params): Promise<PaginationResponse<SeasonPeriodEntity>> {
    this.indexManager.setFilterParam(params);
    this.indexManager.setService(this.serviceData, TABLE_NAME.SEASON_PERIOD);
    await this.indexManager.execute();
    return this.indexManager.getResult();
  }

  async detail(dataId: string): Promise<SeasonPeriodEntity> {
    this.detailManager.setData(dataId);
    this.detailManager.setService(this.serviceData, TABLE_NAME.SEASON_PERIOD);
    await this.detailManager.execute();
    return this.detailManager.getResult();
  }
}
